@@ -4,20 +4,23 @@
 to check if it imports any variable don't owned by any true module.
 """
 import logging as _logging
-from typing import NoReturn
+import sys
+from typing import Any, NoReturn
 
 _logger = _logging.getLogger(__name__)
 
 
-def dump(*args, **kwargs) -> NoReturn:
-    """dump.
+def dump(*args: Any, **kwargs: Any) -> NoReturn:
+    """Dump.
 
     :param args:
+    :type args: Any
     :param kwargs:
+    :type kwargs: Any
     :rtype: NoReturn
     """
     _logger.error("Please install pyyaml firstly!")
-    exit(1)
+    sys.exit(1)
 
 
 if __name__ == "__main__":
