@@ -4,7 +4,7 @@ from .. import TRANSLATION
 
 
 def parse_tokens(tokens: list[str], res: TRANSLATION) -> TRANSLATION:
-    """parse_tokens.
+    """Parse tokens.
 
     :param tokens:
     :type tokens: list[str]
