@@ -17,7 +17,7 @@ def get_setting(name: str | None) -> str:
     elif name == "dictionary_dirs":
         from .. import STARDICT_DIRS
 
-        result = "\n".join(STARDICT_DIRS)
+        result = "\n".join(map(str, STARDICT_DIRS))
     elif name == "translators":
         from ..translators import TRANSLATORS
 
@@ -35,16 +35,16 @@ def get_setting(name: str | None) -> str:
 
         result = " ".join(get_clipper())
     elif name == "speaker":
-        from .speakers import get_speaker
+        from ..translators.speaker import Speaker
 
-        result = " ".join(get_speaker("")).strip()
+        result = " ".join(Speaker.get_speaker("")).strip()
     elif name is None:
         from ..__main__ import SETTINGS
 
         result = "\n".join(SETTINGS)
     else:
         result = ""
-    return result
+    return str(result)
 
 
 def print_setting(name: str) -> int:
