@@ -5,4 +5,4 @@ Provide assets path.
 """
 from pathlib import Path
 
-ASSETS_PATH = Path(__file__).absolute().parent.parent / "assets"
+ASSETS_PATH = Path(__file__).absolute().parent
