@@ -1,8 +1,10 @@
 """Test translators."""
 import json
+import sys
+
+import pytest
 
 from translate_shell.translate import translate
-from translate_shell.translators import TRANSLATORS
 
 from . import ASSETS_PATH
 
@@ -10,7 +12,10 @@ from . import ASSETS_PATH
 class Test:
     """Test."""
 
-    def test_google(self):
+    @pytest.mark.skipif(
+        sys.platform == "win32", reason="'charmap' codec can't decode byte"
+    )
+    def test_google(self) -> None:
         """Test google"""
         rst = vars(translate("The Mythical Man-Month", "zh_TW"))
         expected = json.loads(
